pub enum CrossProcessLockConfig {
MultiProcess {
holder_name: String,
},
SingleProcess,
}Expand description
The cross-process lock config to use for the various stores.
Variants
MultiProcess
The stores will be used in multiple processes, the holder name for the
cross-process lock is the associated String.
SingleProcess
The stores will be used in a single process, there is no need for a cross-process lock.
Implementations
Sourceimpl CrossProcessLockConfig
impl CrossProcessLockConfig
Sourcepub fn multi_process(holder_name: impl Into<String>) -> Self
pub fn multi_process(holder_name: impl Into<String>) -> Self
Helper for quickly creating a CrossProcessLockConfig::MultiProcess
variant.
Sourcepub fn holder_name(&self) -> Option<&str>
pub fn holder_name(&self) -> Option<&str>
The holder name for the cross-process lock. This is only relevant for
CrossProcessLockConfig::MultiProcess variants.